/* set up your libname */
libname big 'xxx';

ods _all_ close; 
ods listing image_dpi=200 style=htmlBlue;
ods graphics / reset width=6in imagename='heatbox' antiAliasMax=1400000;

data box_heat;
  set big.air_ontime_2012_q1;
  where arr_delay > -30 AND arr_delay < 60;
  keep unique_carrier arr_delay;
run;

proc means data=box_heat;
  class unique_carrier;
  output out=numObs(keep=unique_carrier _freq_ ) n=;
run;

data box_heat_final;
  merge box_heat numObs( rename=(unique_carrier=ucc)
                          where=(ucc NE ' ') );
run;

proc sgplot data=box_heat_final noAutoLegend;
title "2012 Q1 Airline Arrival Delays in [-30, 60] min Range";
  label unique_carrier="Unique Carrier Code" arr_delay="Arrival Delay (mins)"
        _freq_="Count";
  heatmap x=unique_carrier y=arr_delay / name="heatmap" 
        yBinSize=5 colorModel=(white yellow red);
  vbox arr_delay / category=unique_carrier nofill nooutliers
        whiskerAttrs=(color=black);
  series x=ucc y=_freq_ / y2axis markers; 
  xaxis grid;
  yaxis offsetMin=0.2;
  y2Axis offsetMax=0.85 grid labelpos=dataCenter; 
  gradLegend "heatmap" / position=bottom ;
run;
title;
